"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ACLEnum = exports.EnvironmentEnum = exports.LambdaInvocationTypeEnum = exports.ChronosS3Service = exports.ChronosLambdaClientService = exports.NotificationVars = exports.BusinessNotificationData = exports.BusinessEvent = exports.BusinessNotificationTopicService = exports.validateAndConvert = exports.AppionTopicService = exports.NotificationTopicService = exports.AuthUserModel = exports.SendToCRMService = exports.Commons = void 0;
const core_1 = __importDefault(require("@middy/core"));
const ErrorHandlerService_1 = require("./services/ErrorHandlerService");
const ErrorCodes_1 = require("./models/ErrorCodes");
const Constants_1 = require("./models/Constants");
const AuthUserModel_1 = require("./models/AuthUserModel");
const warmUpMiddleware_1 = __importDefault(require("./middlewares/warmUpMiddleware"));
class Commons {
    warmLambdaFunction(event, context) {
        if (event.source === Constants_1.WARM_SOURCE) {
            return context.succeed(Constants_1.WARM_LAMBDA_MESSAGE);
        }
    }
    apiWarning(payload, warningMessage, statusCode = Constants_1.HTTP_SUCCESS_CODE) {
        return {
            statusCode,
            headers: {
                'Access-Control-Allow-Headers': 'Content-Type',
                'Access-Control-Allow-Origin': '*',
                'Access-Control-Allow-Methods': '*'
            },
            body: JSON.stringify({
                data: payload,
                notification: this.warningNotification(warningMessage)
            })
        };
    }
    apiSuccess(payload, statusCode = Constants_1.HTTP_SUCCESS_CODE) {
        return {
            statusCode,
            headers: {
                'Access-Control-Allow-Headers': 'Content-Type',
                'Access-Control-Allow-Origin': '*',
                'Access-Control-Allow-Methods': '*'
            },
            body: JSON.stringify({
                data: payload,
                notification: this.successfulNotification()
            })
        };
    }
    apiSuccessZip(file, name, statusCode = Constants_1.HTTP_SUCCESS_CODE) {
        return {
            statusCode,
            headers: {
                'Content-Type': 'application/zip',
                'Content-disposition': 'attachment; filename=' + name + '.zip'
            },
            body: file,
            isBase64Encoded: true
        };
    }
    lambdaSuccess(payload) {
        return {
            statusCode: Constants_1.HTTP_SUCCESS_CODE,
            body: JSON.stringify(payload)
        };
    }
    errorHandler(baseHandler) {
        const isWarmingUp = (event) => event.isWarmingUp === true;
        const handled = (0, core_1.default)(baseHandler).use((0, warmUpMiddleware_1.default)({ isWarmingUp }));
        handled.onError(async (request) => {
            const errorH = new ErrorHandlerService_1.ErrorHandlerService();
            return errorH.handleError(request);
        });
        return handled;
    }
    successfulNotification() {
        ErrorCodes_1.SUCCESSFUL_NOTIFICATION.timestamp = new Date();
        return ErrorCodes_1.SUCCESSFUL_NOTIFICATION;
    }
    warningNotification(message) {
        ErrorCodes_1.WARNING_NOTIFICATION.message = message;
        ErrorCodes_1.WARNING_NOTIFICATION.timestamp = new Date();
        return ErrorCodes_1.WARNING_NOTIFICATION;
    }
    /**
     * Extract authenticated user from Api Gateway event
     * @param event is Api Gateway event
     */
    static extractAuthUser(event) {
        var _a;
        let userClaims;
        try {
            userClaims = (_a = event.requestContext.authorizer.claims) !== null && _a !== void 0 ? _a : event.requestContext.authorizer;
            if (Constants_1.EXTERNAL_VALIDATION_PROVIDERS.includes(userClaims.iss)) {
                //In future iterations, create a differente AuthUserModel depending on the provider
                return new AuthUserModel_1.AuthUserModel(userClaims.sub, null, userClaims.name, null, userClaims.email, event.headers.Authorization, userClaims.brokerType, userClaims.role_SOC, false, null);
            }
            if (userClaims.token_use === 'access') {
                return new AuthUserModel_1.AuthUserModel(null, null, null, null, null, event.headers.Authorization, null, null, true, userClaims.client_id);
            }
            else {
                return new AuthUserModel_1.AuthUserModel(userClaims.sub, userClaims['custom:lead_id'], userClaims.nickname, userClaims.phone_number, userClaims.email, event.headers.Authorization, userClaims['custom:department'], userClaims['custom:position'], false, null);
            }
        }
        catch (error) {
            console.error(error);
            throw Error('user_auth_error: Cognito UserModel in Authorization Token is not present');
        }
    }
    /**
     * This method extract Client User and Executive User from API GW event that comes from either Broker resource (/broker/executive/...) resource or self-service
     * @param event is AWS ApiGateway lambda proxy event
     * @param userDataServiceInstance is the instance of user data client that connects to users DB table
     * @param executiveDataService is the instance of executive user data client that connects to executives DB table
     * @returns ClientAndExecutiveUsers that has clientUser, executiveUser, isFromBroker and isClientCredentials properties
     */
    static async getExecutiveAndFinalUserFromEvent(event, userDataServiceInstance, executiveDataService) {
        let clientUser;
        let executiveUser;
        let isFromBroker = false;
        let isClientCredentials = false;
        if (event.resource.includes(Constants_1.ResourcePath.PATH_BROKER_EXECUTIVE)) { //if request comes from /broker resource...
            executiveUser = Commons.extractAuthUser(event); //Extract executiveUser from event
            if (executiveUser.isClientCredentials) { //if request is from an Application (Authenticated with client credentials) then retrieve executiveUser from DB
                isClientCredentials = true;
                const executiveUserData = await executiveDataService.getUser({ id: event.headers['executive-id'] });
                if (!Object.keys(executiveUserData).length)
                    throw Error('User_Data_Does_Not_Exists');
                executiveUser = {
                    id: executiveUserData.id,
                    email: executiveUserData.email,
                    phoneNumber: executiveUserData.phone_number,
                    isClientCredentials: true
                };
            }
            //Get clientUser from DB
            if (event.pathParameters && event.pathParameters['user-id']) { //if pathParameters and 'user-id' pathParam property exists then retrieve clientUser from DB, otherwise it means creation of a new user
                const userData = await userDataServiceInstance.getUser({ id: event.pathParameters['user-id'] });
                if (!Object.keys(userData).length)
                    throw Error('User_Data_Does_Not_Exists');
                clientUser = {
                    id: userData.id,
                    email: userData.email,
                    leadId: userData.lead_id,
                    nickName: userData.nick_name,
                    phoneNumber: userData.phone_number,
                    isClientCredentials: false
                };
            }
            isFromBroker = true;
        }
        else { //Otherwise, request is from slef-service, then only return clientUser
            clientUser = Commons.extractAuthUser(event);
        }
        return { clientUser, executiveUser, isFromBroker, isClientCredentials };
    }
}
exports.Commons = Commons;
var SendToCRMService_1 = require("./services/SendToCRMService");
Object.defineProperty(exports, "SendToCRMService", { enumerable: true, get: function () { return SendToCRMService_1.SendToCRMService; } });
var AuthUserModel_2 = require("./models/AuthUserModel");
Object.defineProperty(exports, "AuthUserModel", { enumerable: true, get: function () { return AuthUserModel_2.AuthUserModel; } });
var NotificationTopicService_1 = require("./services/NotificationTopicService");
Object.defineProperty(exports, "NotificationTopicService", { enumerable: true, get: function () { return NotificationTopicService_1.NotificationTopicService; } });
var AppionTopicService_1 = require("./services/AppionTopicService");
Object.defineProperty(exports, "AppionTopicService", { enumerable: true, get: function () { return AppionTopicService_1.AppionTopicService; } });
var ClassValidationService_1 = require("./services/ClassValidationService");
Object.defineProperty(exports, "validateAndConvert", { enumerable: true, get: function () { return ClassValidationService_1.validateAndConvert; } });
var BuisnessNotificationTopicService_1 = require("./services/BuisnessNotificationTopicService");
Object.defineProperty(exports, "BusinessNotificationTopicService", { enumerable: true, get: function () { return BuisnessNotificationTopicService_1.BusinessNotificationTopicService; } });
var BusinessEventModel_1 = require("./models/BusinessEventModel");
Object.defineProperty(exports, "BusinessEvent", { enumerable: true, get: function () { return BusinessEventModel_1.BusinessEvent; } });
Object.defineProperty(exports, "BusinessNotificationData", { enumerable: true, get: function () { return BusinessEventModel_1.BusinessNotificationData; } });
Object.defineProperty(exports, "NotificationVars", { enumerable: true, get: function () { return BusinessEventModel_1.NotificationVars; } });
var ChronosLambdaClientService_1 = require("./services/ChronosLambdaClientService");
Object.defineProperty(exports, "ChronosLambdaClientService", { enumerable: true, get: function () { return ChronosLambdaClientService_1.ChronosLambdaClientService; } });
var ChronosS3Service_1 = require("./services/ChronosS3Service");
Object.defineProperty(exports, "ChronosS3Service", { enumerable: true, get: function () { return ChronosS3Service_1.ChronosS3Service; } });
var Enums_1 = require("./models/Enums");
Object.defineProperty(exports, "LambdaInvocationTypeEnum", { enumerable: true, get: function () { return Enums_1.LambdaInvocationTypeEnum; } });
Object.defineProperty(exports, "EnvironmentEnum", { enumerable: true, get: function () { return Enums_1.EnvironmentEnum; } });
Object.defineProperty(exports, "ACLEnum", { enumerable: true, get: function () { return Enums_1.ACLEnum; } });
//# sourceMappingURL=index.js.map