import { FileUploadResponse } from '../models/FileUploadResponse';
import { ACLEnum } from '../models/Enums';
export interface IChronosS3Service {
    /**
     * It generates a signed URL for the file to be uploaded
     * @param {string} keyName - The name of the file you want to upload.
     * @param {ACL} [acl] - The access control list for the file. ('private',
     'public-read',
     'public-read-write',
     'aws-exec-read',
     'authenticated-read',
     'bucket-owner-read',
     'bucket-owner-full-control',
     'log-delivery-write')
     @returns FileUploadResponse an object with two properties:
     * - resource_url and upload_url
     */
    generateSignedUrl(keyName: string, acl?: ACLEnum): Promise<FileUploadResponse>;
    /**
     * It takes a key name and a base64 encoded file and stores it in the S3 bucket
     * @param {string} keyName - The name of the file you want to store in S3.
     * @param {string} contentFile - The file content in base64 format.
     * @param ACL
     * @param contentType
     * @returns The location and key of the file that was stored.
     */
    storeFile(keyName: string, contentFile: string, ACL?: string, contentType?: string): Promise<Record<string, string>>;
    /**
     * It takes in a boolean value, and either an objectUrl or an objectKey, and returns a base64 encoded string of the file
     * @param {boolean} getByUrl - boolean - If true, the objectUrl parameter will be used to get the file. If false, the
     * objectKey parameter will be used.
     * @param {string} [objectUrl] - The URL of the object you want to get.
     * @param {string} [objectKey] - The name of the file you want to get.
     * @returns The file is being returned as a base64 encoded string.
     */
    getFile(getByUrl: boolean, objectUrl?: string, objectKey?: string): Promise<string>;
    /**
     * Deletes a file with the given key from the specified URL.
     * @param {string} url - The URL of the file to delete.
     * @param {string} key - The key of the file to delete.
     * @returns A Promise that resolves with no value upon successful deletion of the file.
     */
    deleteFile(url?: string, key?: string): Promise<void>;
}
