import { IChronosS3Service } from '../interfaces/IChronosS3Service';
import { FileUploadResponse } from '../models/FileUploadResponse';
import { ACLEnum } from '../models/Enums';
export declare class ChronosS3Service implements IChronosS3Service {
    private readonly AWS_REGION;
    private readonly BUCKET_NAME;
    private readonly s3;
    /**
     * @param AWS_REGION is AWS region
     * @param BUCKET_NAME is Bucket name to upload or get some object
     */
    constructor(AWS_REGION: string, BUCKET_NAME: string);
    /**
     * It generates a signed URL for the file to be uploaded
     * @param {string} keyName - The name of the file you want to upload.
     * @param {ACL} [acl] - The access control list for the file. ('private',
     'public-read',
     'public-read-write',
     'aws-exec-read',
     'authenticated-read',
     'bucket-owner-read',
     'bucket-owner-full-control',
     'log-delivery-write''
     */
    generateSignedUrl(keyName: string, acl?: ACLEnum): Promise<FileUploadResponse>;
    /**
     * It takes a key name and a base64 encoded file and stores it in the S3 bucket
     * @param {string} keyName - The name of the file you want to store in S3.
     * @param {string} contentFile - The file content in base64 format.
     * @param {string} ACL - indicates the ACL property of the S3 bucket object, default is public read (public-read)
     * @param contentType
     * @returns The location and key of the file that was stored.
     */
    storeFile(keyName: string, contentFile: string, ACL?: string, contentType?: string): Promise<Record<string, string>>;
    /**
     * It takes in a boolean value, and either an objectUrl or an objectKey, and returns a base64 encoded string of the file
     * @param {boolean} getByUrl - boolean - If true, the objectUrl parameter is required, will be used to get the file. If false, the
     * objectKey parameter will be used.
     * @param {string} [objectUrl] - The URL of the object you want to get.
     * @param {string} [objectKey] - The name of the file you want to get.
     * @returns The file is being returned as a base64 encoded string.
     */
    getFile(getByUrl: boolean, objectUrl?: string, objectKey?: string): Promise<string>;
    /**
     * Deletes a file from the S3 bucket.
     * @param {string} url - The URL of the file to delete.
     * @param {string} key - The key of the file to delete.
     * @returns {Promise<void>} - A promise that resolves when the file is deleted.
     * @throws {Error} - If neither url nor key is provided, an error is thrown.
     */
    deleteFile(url?: string, key?: string): Promise<void>;
}
