"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChronosS3Service = void 0;
const client_s3_1 = require("@aws-sdk/client-s3");
const s3_request_presigner_1 = require("@aws-sdk/s3-request-presigner");
const Enums_1 = require("../models/Enums");
class ChronosS3Service {
    /**
     * @param AWS_REGION is AWS region
     * @param BUCKET_NAME is Bucket name to upload or get some object
     */
    constructor(AWS_REGION, BUCKET_NAME) {
        this.AWS_REGION = AWS_REGION;
        this.BUCKET_NAME = BUCKET_NAME;
        this.s3 = new client_s3_1.S3Client({
            region: this.AWS_REGION
        });
    }
    /**
     * It generates a signed URL for the file to be uploaded
     * @param {string} keyName - The name of the file you want to upload.
     * @param {ACL} [acl] - The access control list for the file. ('private',
     'public-read',
     'public-read-write',
     'aws-exec-read',
     'authenticated-read',
     'bucket-owner-read',
     'bucket-owner-full-control',
     'log-delivery-write''
     */
    async generateSignedUrl(keyName, acl) {
        const params = new client_s3_1.GetObjectCommand({
            Bucket: this.BUCKET_NAME,
            Key: keyName
        });
        try {
            const signedUrl = await (0, s3_request_presigner_1.getSignedUrl)(this.s3, params, { expiresIn: 60 * 15 });
            console.info('SIGNED URL GENERATED:::', signedUrl);
            const fileUrl = signedUrl.split('?')[0];
            console.info('URL FILE:::', fileUrl);
            return {
                resource_url: fileUrl,
                upload_url: signedUrl
            };
        }
        catch (e) {
            console.error('SOMETHING ERROR:::', e);
            throw Error(`Dynamic_Error generate_signed_url_failed ${e}`);
        }
    }
    /**
     * It takes a key name and a base64 encoded file and stores it in the S3 bucket
     * @param {string} keyName - The name of the file you want to store in S3.
     * @param {string} contentFile - The file content in base64 format.
     * @param {string} ACL - indicates the ACL property of the S3 bucket object, default is public read (public-read)
     * @param contentType
     * @returns The location and key of the file that was stored.
     */
    async storeFile(keyName, contentFile, ACL = 'public-read', contentType) {
        const bodyFile = Buffer.from(contentFile, 'base64');
        const params = new client_s3_1.PutObjectCommand({
            Bucket: this.BUCKET_NAME,
            Key: keyName,
            Body: bodyFile,
            ContentEncoding: 'base64',
            ACL: Enums_1.ACLEnum[ACL] || 'public-read'
        });
        if (contentType)
            params.input.ContentType = contentType;
        try {
            const response = await this.s3.send(params);
            console.info('RESPONSE:::', response);
            return {
                Location: `https://s3.amazonaws.com/${this.BUCKET_NAME}/${keyName}`,
                Key: keyName
            };
        }
        catch (e) {
            console.error(e);
            throw Error(`Dynamic_Error store_file_failed ${e}`);
        }
    }
    /**
     * It takes in a boolean value, and either an objectUrl or an objectKey, and returns a base64 encoded string of the file
     * @param {boolean} getByUrl - boolean - If true, the objectUrl parameter is required, will be used to get the file. If false, the
     * objectKey parameter will be used.
     * @param {string} [objectUrl] - The URL of the object you want to get.
     * @param {string} [objectKey] - The name of the file you want to get.
     * @returns The file is being returned as a base64 encoded string.
     */
    async getFile(getByUrl, objectUrl, objectKey) {
        let keyName;
        if (getByUrl) {
            const splitUrl = objectUrl.split('/');
            keyName = splitUrl[splitUrl.length - 1];
        }
        else {
            keyName = objectKey;
        }
        const params = new client_s3_1.GetObjectCommand({
            Bucket: this.BUCKET_NAME,
            Key: keyName
        });
        try {
            const s3Data = await this.s3.send(params);
            return s3Data.Body.transformToString();
        }
        catch (e) {
            console.error(e);
            throw Error(`Dynamic_Error get_file_error ${e}`);
        }
    }
    /**
     * Deletes a file from the S3 bucket.
     * @param {string} url - The URL of the file to delete.
     * @param {string} key - The key of the file to delete.
     * @returns {Promise<void>} - A promise that resolves when the file is deleted.
     * @throws {Error} - If neither url nor key is provided, an error is thrown.
     */
    async deleteFile(url = null, key = null) {
        let keyName;
        if (!key && url !== null) {
            keyName = url.split('.com/')[1];
            keyName = keyName.replace(/%3A/g, ':');
        }
        else if (key) {
            keyName = key;
        }
        else {
            throw Error('Dynamic_Error delete_file_error no_url_or_key_provided');
        }
        const params = {
            Bucket: this.BUCKET_NAME,
            Key: keyName
        };
        try {
            const data = await this.s3.send(new client_s3_1.DeleteObjectCommand(params));
            console.info('DELETE FILE RESPONSE:::', data);
        }
        catch (e) {
            console.error(e);
            throw Error(`Dynamic_Error delete_file_error ${e}`);
        }
    }
}
exports.ChronosS3Service = ChronosS3Service;
//# sourceMappingURL=ChronosS3Service.js.map